@@ -42,6 +42,10 @@ class InputSpace:
             y_rot = np.cos(rot + np.pi / 2) * x + np.sin(rot + np.pi / 2) * y
             x, y = x_rot, y_rot
 
+        # periodic function
+        if params.periodic_function:
+            x, y = np.sin(x), np.sin(y)
+
         x = x.reshape(-1, 1)
         y = y.reshape(-1, 1)
 
